Array Manipulation
##################

LibRapid arrays support powerful manipulation routines which
support data permanence (as far as possible) and optimized
implementations. They allow for complex algorithms to be implemented
easily, and data accesses to be simplified dramatically.

.. Attention::

	Some manipulation routines do **NOT** result in data
	permanence, and will result in a copied array. Please
	ensure you are aware of this, as it may lead to
	undesired results

.. toctree::
	:maxdepth: 2
	:glob:

	array_manipulation_reshape
